@@ -607,7 +607,9 @@ char* ExpSep::State(void)
  * log_Prior:
  * 
  * compute the (log) prior for the parameters to
- * the correlation function (e.g. d and nug)
+ * the correlation function (e.g. d and nug).  Does not
+ * include hierarchical prior params; see log_HierPrior
+ * below
  */
 
 double ExpSep::log_Prior(void)
@@ -1008,7 +1010,7 @@ double ExpSep_Prior::log_Prior(double *d, int *b, double *pb, bool linear)
 
   /* sum the log priors for each of the d-parameters */
   for(unsigned int i=0; i<col-1; i++)
-    prob += d_prior_pdf(d[i], d_alpha[i], d_beta[i]);
+    prob += log_d_prior_pdf(d[i], d_alpha[i], d_beta[i]);
 
   /* if not allowing the LLM, then we're done */
   if(gamlin[0] <= 0) return prob;
@@ -1042,7 +1044,7 @@ double ExpSep_Prior::log_DPrior_pdf(double *d)
 {
   double p = 0;
   for(unsigned int i=0; i<col-1; i++) {
-    p += d_prior_pdf(d[i], d_alpha[i], d_beta[i]);
+    p += log_d_prior_pdf(d[i], d_alpha[i], d_beta[i]);
   }
   return p;
 }
@@ -1095,7 +1097,7 @@ void ExpSep_Prior::Print(FILE *outfile)
 {
   myprintf(stdout, "corr prior: separable power\n");
 
-  /* print nugget stugg first */
+  /* print nugget stuff first */
   PrintNug(outfile);
 
   /* range parameter */
@@ -1116,6 +1118,33 @@ void ExpSep_Prior::Print(FILE *outfile)
   if(fix_d) myprintf(outfile, "d prior fixed\n");
   else {
     myprintf(stdout, "d lambda[a,b][0,1]=[%g,%g],[%g,%g]\n", 
-	     d_alpha_lambda[0], d_beta_lambda[0], d_alpha_lambda[1], d_beta_lambda[1]);
+	     d_alpha_lambda[0], d_beta_lambda[0], d_alpha_lambda[1], 
+	     d_beta_lambda[1]);
   }
 }
+
+
+/*
+ * log_HierPrior:
+ *
+ * return the log prior of the hierarchial parameters
+ * to the correllation parameters (i.e., range and nugget)
+ */
+
+double ExpSep_Prior::log_HierPrior(void)
+{
+  double lpdf, p;
+  lpdf = 0.0;
+
+  /* mixture prior for the range parameter, d */
+  if(!fix_d) {
+    for(unsigned int i=0; i<col-1; i++)
+      lpdf += mixture_hier_prior_log(d_alpha[i], d_beta[i], 
+				     d_alpha_lambda, d_beta_lambda);
+  }
+
+  /* mixture prior for the nugget */
+  lpdf += log_NugHierPrior();
+
+  return lpdf;
+}
