@@ -118,9 +118,9 @@ MrExp::~MrExp(void)
  * return true if the correlation matrix has changed; false otherwise
  */
 
-bool MrExp::DrawNug(unsigned int n, double **X, 
-		    double **F, double *Z, double *lambda, 
-		   double **bmu, double **Vb, double tau2, void *state)
+bool MrExp::DrawNug(unsigned int n, double **X, double **F, double *Z, 
+		    double *lambda, double **bmu, double **Vb, double tau2, 
+		    void *state)
 {
   bool success = false;
   MrGp_Prior *gp_prior = (MrGp_Prior*) base_prior;
@@ -133,9 +133,10 @@ bool MrExp::DrawNug(unsigned int n, double **X,
   /* make the draw */
   double nug_new = 
     nug_draw_margin(n, col, nug, F, Z, K, log_det_K, *lambda, Vb, K_new, Ki_new, 
-		    Kchol_new, &log_det_K_new, &lambda_new, Vb_new, bmu_new, gp_prior->get_b0(), 
-		    gp_prior->get_Ti(), gp_prior->get_T(), tau2, prior->NugAlpha(), prior->NugBeta(), 
-		    gp_prior->s2Alpha(), gp_prior->s2Beta(), (int) linear, state);
+		    Kchol_new, &log_det_K_new, &lambda_new, Vb_new, bmu_new, 
+		    gp_prior->get_b0(), gp_prior->get_Ti(), gp_prior->get_T(), 
+		    tau2, prior->NugAlpha(), prior->NugBeta(), gp_prior->s2Alpha(), 
+		    gp_prior->s2Beta(), (int) linear, state);
   
   /* did we accept the draw? */
   if(nug_new != nug) { nug = nug_new; success = true; swap_new(Vb, bmu, lambda); }
@@ -191,7 +192,8 @@ void MrExp::Update(unsigned int n, double **K, double **X)
  * returns a correlation matrix
  */
 
-void MrExp::Update(unsigned int n1, unsigned int n2, double **K, double **X, double **XX)
+void MrExp::Update(unsigned int n1, unsigned int n2, double **K, double **X, 
+		   double **XX)
 {
   double **xxDISTx = new_matrix(n2, n1);
   double **XXc = new_shift_matrix(XX, n1, dim+1);
@@ -221,7 +223,8 @@ int MrExp::Draw(unsigned int n, double **F, double **X, double *Z,
   double q_fwd , q_bak, d_new;
 
   /* sometimes skip this Draw for linear models for speed */
-  if(linear && runi(state) > 0.5) return DrawNug(n, X, F, Z, lambda, bmu, Vb, tau2, state);
+  if(linear && runi(state) > 0.5) 
+    return DrawNug(n, X, F, Z, lambda, bmu, Vb, tau2, state);
 
   /* proppose linear or not */
   if(prior->Linear()) lin_new = true;
@@ -427,7 +430,9 @@ double MrExp::D(void)
  * log_Prior:
  * 
  * compute the (log) prior for the parameters to
- * the correlation function (e.g. d and nug)
+ * the correlation function (e.g. d and nug). Does not
+ * include hierarchical prior params; see log_HierPrior
+ * below
  */
 
 double MrExp::log_Prior(void)
@@ -708,7 +713,7 @@ double MrExp_Prior::log_Prior(double d, bool linear)
 {
   double prob = 0;
   if(gamlin[0] < 0) return prob;
-  prob += d_prior_pdf(d, d_alpha, d_beta);
+  prob += log_d_prior_pdf(d, d_alpha, d_beta);
   if(gamlin[0] <= 0) return prob;
   double lin_pdf = linear_pdf(&d, 1, gamlin);
   if(linear) prob += log(lin_pdf);
@@ -751,7 +756,7 @@ void MrExp_Prior::Print(FILE *outfile)
 {
   myprintf(stdout, "corr prior: isotropic power\n");
 
-  /* print nugget stugg first */
+  /* print nugget stuff first */
   PrintNug(outfile);
 
   /* range parameter */
@@ -765,6 +770,32 @@ void MrExp_Prior::Print(FILE *outfile)
   if(fix_d) myprintf(outfile, "d prior fixed\n");
   else {
     myprintf(stdout, "d lambda[a,b][0,1]=[%g,%g],[%g,%g]\n", 
-	     d_alpha_lambda[0], d_beta_lambda[0], d_alpha_lambda[1], d_beta_lambda[1]);
+	     d_alpha_lambda[0], d_beta_lambda[0], d_alpha_lambda[1], 
+	     d_beta_lambda[1]);
   }
 }
+
+
+/*
+ * log_HierPrior:
+ *
+ * return the log prior of the hierarchial parameters
+ * to the correllation parameters (i.e., range and nugget)
+ */
+
+double MrExp_Prior::log_HierPrior(void)
+{
+ double lpdf, p;
+ 
+ lpdf = 0.0;
+
+  /* mixture prior for the range parameter, d */
+  if(!fix_d) {
+    lpdf += mixture_hier_prior_log(d_alpha, d_beta, d_alpha_lambda, d_beta_lambda);
+  }
+
+  /* mixture prior for the nugget */
+  lpdf += log_NugHierPrior();
+
+  return lpdf;
+}
